@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command;
 BEGIN {
-  $Dist::Zilla::App::Command::VERSION = '3.101390';
+  $Dist::Zilla::App::Command::VERSION = '4.101800';
 }
 # ABSTRACT: base class for dzil commands
 use App::Cmd::Setup -command;
@@ -13,12 +13,6 @@ sub zilla {
   return $_[0]->app->zilla;
 }
 
-sub config {
-  my ($self) = @_;
-  return $self->{'' . __PACKAGE__}{config}
-    ||= $self->zilla->_global_config_for(ref $self);
-}
-
 
 sub log {
   $_[0]->app->chrome->logger->log($_[1]);
@@ -35,7 +29,7 @@ Dist::Zilla::App::Command - base class for dzil commands
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 METHODS
 
@@ -52,7 +46,7 @@ This method calls the C<log> method of the application's chrome.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
