@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::clean;
 BEGIN {
-  $Dist::Zilla::App::Command::clean::VERSION = '3.101390';
+  $Dist::Zilla::App::Command::clean::VERSION = '4.101800';
 }
 # ABSTRACT: clean up after build, test, or install
 use Dist::Zilla::App -command;
@@ -29,28 +29,20 @@ Dist::Zilla::App::Command::clean - clean up after build, test, or install
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 SYNOPSIS
 
-Removes some files that are created during build, test, and install.
+  dzil clean
 
-    dzil clean
-
-=head1 REMOVED FILES
-
-    ^.build
-    ^<distribution-name>-*
-
-ie:
-
-    removing .build
-    removing Foo-Bar-1.09010
-    removing Foo-Bar-1.09010.tar.gz
+This command removes some files that are created during build, test, and
+install.  It's a very thin layer over the C<L<clean|Dist::Zilla/clean>> method
+on the Dist::Zilla object.  The documentation for that method gives more
+information about the files that will be removed.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
