@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::install;
 BEGIN {
-  $Dist::Zilla::App::Command::install::VERSION = '3.101390';
+  $Dist::Zilla::App::Command::install::VERSION = '4.101800';
 }
 # ABSTRACT: install your dist
 use Dist::Zilla::App -command;
@@ -19,7 +19,9 @@ sub execute {
   my ($self, $opt, $arg) = @_;
 
   $self->zilla->install({
-    ($opt->install_command ? (install_command => $opt->install_command) : ()),
+    $opt->install_command
+      ? (install_command => [ $opt->install_command ])
+      : (),
   });
 }
 
@@ -34,7 +36,7 @@ Dist::Zilla::App::Command::install - install your dist
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 SYNOPSIS
 
@@ -55,13 +57,16 @@ This defines what command to run after building the dist in the dist dir.
 
 Any value that works with L<C<system>|perlfunc/system> is accepted.
 
-If not specified, calls
+If not specified, calls (roughly):
 
     perl -MCPAN -einstall "."
 
+For more information, look at the L<install|Dist::Zilla/install> method in
+Dist::Zilla.
+
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
