@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::nop;
 BEGIN {
-  $Dist::Zilla::App::Command::nop::VERSION = '3.101390';
+  $Dist::Zilla::App::Command::nop::VERSION = '4.101800';
 }
 # ABSTRACT: initialize dzil, then exit
 use Dist::Zilla::App -command;
@@ -10,9 +10,6 @@ use Dist::Zilla::App -command;
 
 sub abstract { 'do nothing: initialize dzil, then exit' }
 
-sub opt_spec {
-}
-
 sub execute {
   my ($self, $opt, $arg) = @_;
 
@@ -30,18 +27,21 @@ Dist::Zilla::App::Command::nop - initialize dzil, then exit
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 SYNOPSIS
 
 This command does nothing.  It initializes Dist::Zill, then exits.  This is
 useful to see the logging output of plugin initialization.
 
-    dzil nop -v
+  dzil nop -v
+
+Seriously, this command is almost entirely for diagnostic purposes.  Don't
+overthink it, okay?
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
