@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::release;
 BEGIN {
-  $Dist::Zilla::App::Command::release::VERSION = '3.101390';
+  $Dist::Zilla::App::Command::release::VERSION = '4.101800';
 }
 # ABSTRACT: release your dist to the CPAN
 use Dist::Zilla::App -command;
@@ -35,20 +35,22 @@ Dist::Zilla::App::Command::release - release your dist to the CPAN
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 SYNOPSIS
 
-Use ReleasePlugin(s) to release your distribution in many ways.
+  dzil release
 
-    dzil release
+  dzil release --trial
 
-Put some plugins in your F<dist.ini> that perform
-L<Dist::Zilla::Role::Releaser>, such as L<Dist::Zilla::Plugin::UploadToCPAN>
+This command is a very, very thin wrapper around the
+C<L<release|Dist::Zilla/release>> method on the Dist::Zilla object.  It will
+build, archive, and release your distribution using your Releaser plugins.  The
+only option, C<--trial>, will cause it to build a trial build.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
