@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::test;
 BEGIN {
-  $Dist::Zilla::App::Command::test::VERSION = '3.101390';
+  $Dist::Zilla::App::Command::test::VERSION = '4.101800';
 }
 # ABSTRACT: test your dist
 use Dist::Zilla::App -command;
@@ -29,29 +29,24 @@ Dist::Zilla::App::Command::test - test your dist
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 SYNOPSIS
 
-Test your distribution:
-
   dzil test
 
-This runs with AUTHOR_TESTING and RELEASE_TESTING environment variables turned
-on, so it's like doing this:
+This command is a thin wrapper around the C<L<test|Dist::Zilla/test>> method in
+Dist::Zilla.  It builds your dist and runs the tests with AUTHOR_TESTING and
+RELEASE_TESTING environment variables turned on, so it's like doing this:
 
   export AUTHOR_TESTING=1
   export RELEASE_TESTING=1
-  dzil build
-  rsync -avp My-Project-Version/ .build/
-  cd .build;
+  dzil build --no-tgz
+  cd $BUILD_DIRECTORY
   perl Makefile.PL
   make
   make test
 
-Except for the fact it's built directly in a subdir of .build (like
-F<.build/ASDF123>).
-
 A build that fails tests will be left behind for analysis, and F<dzil> will
 exit a non-zero value.  If the tests are successful, the build directory will
 be removed and F<dzil> will exit with status 0.
@@ -63,7 +58,7 @@ L<Dist::Zilla::Role::TestRunner> plugins.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
