@@ -1,6 +1,6 @@
 package Dist::Zilla::File::OnDisk;
 BEGIN {
-  $Dist::Zilla::File::OnDisk::VERSION = '3.101390';
+  $Dist::Zilla::File::OnDisk::VERSION = '4.101800';
 }
 # ABSTRACT: a file that comes from your filesystem
 use Moose;
@@ -29,6 +29,12 @@ sub _read_file {
 
   my $fname = $self->_original_name;
   open my $fh, '<', $fname or die "can't open $fname for reading: $!";
+
+  # This is needed or \r\n is filtered to be just \n on win32.
+  # Maybe :raw:utf8, not sure.
+  #     -- Kentnl - 2010-06-10
+  binmode $fh, ':raw';
+
   my $content = do { local $/; <$fh> };
 }
 
@@ -47,7 +53,7 @@ Dist::Zilla::File::OnDisk - a file that comes from your filesystem
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 DESCRIPTION
 
@@ -57,7 +63,7 @@ may be altered by plugins.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
