@@ -1,37 +1,40 @@
 package Dist::Zilla::Plugin::DistINI;
 BEGIN {
-  $Dist::Zilla::Plugin::DistINI::VERSION = '3.101390';
+  $Dist::Zilla::Plugin::DistINI::VERSION = '4.101800';
 }
 # ABSTRACT: a plugin to add a dist.ini to newly-minted dists
 use Moose;
 with qw(Dist::Zilla::Role::FileGatherer);
 
-use Dist::Zilla::File::InMemory;
+use Dist::Zilla::File::FromCode;
 
 
 sub gather_files {
   my ($self, $arg) = @_;
 
-  my @core_attrs = qw(name authors copyright_holder);
+  my $zilla = $self->zilla;
+  my $code = sub {
+    my @core_attrs = qw(name authors copyright_holder);
 
-  my $license = ref $self->zilla->license;
-  if ($license =~ /^Software::License::(.+)$/) {
-    $license = $1;
-  } else {
-    $license = "=$license";
-  }
+    my $license = ref $zilla->license;
+    if ($license =~ /^Software::License::(.+)$/) {
+      $license = $1;
+    } else {
+      $license = "=$license";
+    }
 
-  my $content = '';
-  $content .= sprintf "name    = %s\n", $self->zilla->name;
-  $content .= sprintf "author  = %s\n", $_ for @{ $self->zilla->authors };
-  $content .= sprintf "license = %s\n", $license;
-  $content .= sprintf "copyright_holder = %s\n", $self->zilla->copyright_holder;
-  $content .= sprintf "copyright_year   = %s\n", (localtime)[5] + 1900;
-  $content .= "\n";
+    my $content = '';
+    $content .= sprintf "name    = %s\n", $zilla->name;
+    $content .= sprintf "author  = %s\n", $_ for @{ $zilla->authors };
+    $content .= sprintf "license = %s\n", $license;
+    $content .= sprintf "copyright_holder = %s\n", $zilla->copyright_holder;
+    $content .= sprintf "copyright_year   = %s\n", (localtime)[5] + 1900;
+    $content .= "\n";
+  };
 
-  my $file = Dist::Zilla::File::InMemory->new({
-    name    => "dist.ini",
-    content => $content,
+  my $file = Dist::Zilla::File::FromCode->new({
+    name => 'dist.ini',
+    code => $code,
   });
 
   $self->add_file($file);
@@ -50,7 +53,7 @@ Dist::Zilla::Plugin::DistINI - a plugin to add a dist.ini to newly-minted dists
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 DESCRIPTION
 
@@ -64,7 +67,7 @@ In the meantime, you may be happier with a F<dist.ini> template.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
