@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ExtraTests;
 BEGIN {
-  $Dist::Zilla::Plugin::ExtraTests::VERSION = '3.101390';
+  $Dist::Zilla::Plugin::ExtraTests::VERSION = '4.101800';
 }
 # ABSTRACT: rewrite ./xt tests to ./t tests with skips
 use Moose;
@@ -51,7 +51,7 @@ BEGIN {
 }
 |;
 
-  $file->content(join "\n", @lines);
+  $file->content(join "\n", @lines, '');
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -67,7 +67,7 @@ Dist::Zilla::Plugin::ExtraTests - rewrite ./xt tests to ./t tests with skips
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 DESCRIPTION
 
@@ -83,7 +83,7 @@ not set.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
