@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MakeMaker;
 BEGIN {
-  $Dist::Zilla::Plugin::MakeMaker::VERSION = '3.101390';
+  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.101800';
 }
 
 # ABSTRACT: build a Makefile.PL that uses ExtUtils::MakeMaker
@@ -13,6 +13,8 @@ with 'Dist::Zilla::Role::TestRunner';
 with 'Dist::Zilla::Role::TextTemplate';
 
 
+use Config;
+
 use Data::Dumper ();
 use List::MoreUtils qw(any uniq);
 
@@ -24,7 +26,7 @@ my $template = q|
 use strict;
 use warnings;
 
-{{ $perl_prereq ? qq{ BEGIN { require $perl_prereq; } } : ''; }}
+{{ $perl_prereq ? qq[BEGIN { require $perl_prereq; }] : ''; }}
 
 use ExtUtils::MakeMaker {{ $eumm_version }};
 
@@ -34,10 +36,10 @@ my {{ $WriteMakefileArgs }}
 
 unless ( eval { ExtUtils::MakeMaker->VERSION(6.56) } ) {
   my $br = delete $WriteMakefileArgs{BUILD_REQUIRES};
-  my $pp = $WriteMakefileArgs{PREREQ_PM}; 
+  my $pp = $WriteMakefileArgs{PREREQ_PM};
   for my $mod ( keys %$br ) {
     if ( exists $pp->{$mod} ) {
-      $pp->{$mod} = $br->{$mod} if $br->{$mod} > $pp->{$mod}; 
+      $pp->{$mod} = $br->{$mod} if $br->{$mod} > $pp->{$mod};
     }
     else {
       $pp->{$mod} = $br->{$mod};
@@ -62,7 +64,7 @@ sub register_prereqs {
     'ExtUtils::MakeMaker' => $self->eumm_version,
   );
 
-  return unless $self->zilla->_share_dir;
+  return unless keys %{ $self->zilla->_share_dir_map };
 
   $self->zilla->register_prereqs(
     { phase => 'configure' },
@@ -91,10 +93,25 @@ sub setup_installer {
 
   my @share_dir_block = (q{}, q{});
 
-  if (my $share_dir = $self->zilla->_share_dir) {
-    my $share_dir = quotemeta $share_dir;
+
+  my $share_dir_map = $self->zilla->_share_dir_map;
+  if ( keys %$share_dir_map ) {
+    my $preamble = qq{use File::ShareDir::Install;\n};
+
+    if ( my $dist_share_dir = $share_dir_map->{dist} ) {
+      $dist_share_dir = quotemeta $dist_share_dir;
+      $preamble .= qq{install_share dist => "$dist_share_dir";\n};
+    }
+
+    if ( my $mod_map = $share_dir_map->{module} ) {
+      for my $mod ( keys %$mod_map ) {
+        my $mod_share_dir = quotemeta $mod_map->{$mod};
+        $preamble .= qq{install_share module => "$mod", "$mod_share_dir";\n};
+      }
+    }
+
     @share_dir_block = (
-      qq{use File::ShareDir::Install;\ninstall_share "$share_dir";\n},
+      $preamble,
       qq{package\nMY;\nuse File::ShareDir::Install qw(postamble);\n},
     );
   }
@@ -110,6 +127,12 @@ sub setup_installer {
             ->as_string_hash;
   };
 
+  my $build_prereq
+    = $prereqs->requirements_for(qw(build requires))
+    ->clone
+    ->add_requirements($prereqs->requirements_for(qw(test requires)))
+    ->as_string_hash;
+
   my %write_makefile_args = (
     DISTNAME  => $self->zilla->name,
     NAME      => $name,
@@ -120,7 +143,7 @@ sub setup_installer {
     EXE_FILES => [ @exe_files ],
 
     CONFIGURE_REQUIRES => $prereqs_dump->(qw(configure requires)),
-    BUILD_REQUIRES     => $prereqs_dump->(qw(build     requires)),
+    BUILD_REQUIRES     => $build_prereq,
     PREREQ_PM          => $prereqs_dump->(qw(runtime   requires)),
 
     test => { TESTS => join q{ }, sort keys %test_dirs },
@@ -160,11 +183,18 @@ has __write_makefile_args => (
   isa  => 'HashRef',
 );
 
+has 'make_path' => (
+  isa => 'Str',
+  is  => 'ro',
+  default => $Config{make} || 'make',
+);
+
 sub build {
   my $self = shift;
 
+  my $make = $self->make_path;
   system($^X => 'Makefile.PL') and die "error with Makefile.PL\n";
-  system('make')               and die "error running make\n";
+  system($make)                and die "error running $make\n";
 
   return;
 }
@@ -172,8 +202,9 @@ sub build {
 sub test {
   my ( $self, $target ) = @_;
 
+  my $make = $self->make_path;
   $self->build;
-  system('make test') and die "error running make test\n";
+  system($make, 'test') and die "error running $make test\n";
 
   return;
 }
@@ -197,7 +228,7 @@ Dist::Zilla::Plugin::MakeMaker - build a Makefile.PL that uses ExtUtils::MakeMak
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 DESCRIPTION
 
@@ -207,7 +238,7 @@ plugin should also be loaded.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
