@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ModuleBuild;
 BEGIN {
-  $Dist::Zilla::Plugin::ModuleBuild::VERSION = '3.101390';
+  $Dist::Zilla::Plugin::ModuleBuild::VERSION = '4.101800';
 }
 # ABSTRACT: build a Build.PL that uses Module::Build
 use List::MoreUtils qw(any uniq);
@@ -24,19 +24,37 @@ has 'mb_version' => (
   default => '0.3601',
 );
 
+has 'mb_class' => (
+  isa => 'Str',
+  is  => 'rw',
+  default => 'Module::Build',
+);
+
 my $template = q|
 use strict;
 use warnings;
 
 use Module::Build {{ $plugin->mb_version }};
+{{ $plugin->_use_custom_class }}
 
 my {{ $module_build_args }}
 
-my $build = Module::Build->new(%module_build_args);
+my $build = {{ $plugin->mb_class }}->new(%module_build_args);
 
 $build->create_build_script;
 |;
 
+sub _use_custom_class {
+  my ($self) = @_;
+  my $class = $self->mb_class;
+  if ( $class eq 'Module::Build' ) {
+    return "";
+  }
+  else {
+    return "use lib 'inc'; use $class;";
+  }
+}
+
 sub register_prereqs {
   my ($self) = @_;
 
@@ -51,13 +69,8 @@ sub register_prereqs {
   );
 }
 
-sub setup_installer {
-  my ($self, $arg) = @_;
-
-  $self->log_fatal("can't build Build.PL; license has no known META.yml value")
-    unless $self->zilla->license->meta_yml_name;
-
-  (my $name = $self->zilla->name) =~ s/-/::/g;
+sub module_build_args {
+  my ($self) = @_;
 
   my @exe_files =
     $self->zilla->find_files(':ExecFiles')->map(sub { $_->name })->flatten;
@@ -77,7 +90,9 @@ sub setup_installer {
     $prereqs->requirements_for(qw(test requires))
   );
 
-  my %module_build_args = (
+  (my $name = $self->zilla->name) =~ s/-/::/g;
+
+  return {
     module_name   => $name,
     license       => $self->zilla->license->meta_yml_name,
     dist_abstract => $self->zilla->abstract,
@@ -85,15 +100,25 @@ sub setup_installer {
     dist_version  => $self->zilla->version,
     dist_author   => [ $self->zilla->authors->flatten ],
     script_files  => \@exe_files,
-    ($self->zilla->_share_dir ? (share_dir => $self->zilla->_share_dir) : ()),
+    ( keys %{$self->zilla->_share_dir_map} ? (share_dir => $self->zilla->_share_dir_map) : ()),
 
     (map {; $_ => $prereqs{$_}->as_string_hash } keys %prereqs),
-  );
+    recursive_test_files => 1,
+  };
+}
 
-  $self->__module_build_args(\%module_build_args);
+sub setup_installer {
+  my ($self, $arg) = @_;
+
+  $self->log_fatal("can't build Build.PL; license has no known META.yml value")
+    unless $self->zilla->license->meta_yml_name;
+
+  my $module_build_args = $self->module_build_args;
+
+  $self->__module_build_args($module_build_args);
 
   my $module_build_dumper = Data::Dumper->new(
-    [ \%module_build_args ],
+    [ $module_build_args ],
     [ '*module_build_args' ],
   );
   $module_build_dumper->Sortkeys( 1 );
@@ -126,7 +151,7 @@ sub build {
   my $self = shift;
 
   system($^X => 'Build.PL') and die "error with Build.PL\n";
-  system('./Build')         and die "error running ./Build\n";
+  system($^X, 'Build')      and die "error running $^X Build\n";
 
   return;
 }
@@ -135,7 +160,7 @@ sub test {
   my ($self, $target) = @_;
 
   $self->build;
-  system('./Build test') and die "error running ./Build test\n";
+  system($^X, 'Build', 'test') and die "error running $^X Build test\n";
 
   return;
 }
@@ -153,7 +178,7 @@ Dist::Zilla::Plugin::ModuleBuild - build a Build.PL that uses Module::Build
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 DESCRIPTION
 
@@ -168,9 +193,15 @@ B<Optional:> Specify the minimum version of L<Module::Build> to depend on.
 
 Defaults to 0.3601
 
+=head2 mb_class
+
+B<Optional:> Specify the class to use to create the build object.  Defaults
+to C<Module::Build> itself.  If another class is specified, C<use lib 'inc'>
+is also added to the Build.PL file.
+
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
