@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PruneCruft;
 BEGIN {
-  $Dist::Zilla::Plugin::PruneCruft::VERSION = '3.101390';
+  $Dist::Zilla::Plugin::PruneCruft::VERSION = '4.101800';
 }
 # ABSTRACT: prune stuff that you probably don't mean to include
 use Moose;
@@ -23,13 +23,13 @@ sub exclude_file {
 sub prune_files {
   my ($self) = @_;
 
-  my $files = $self->zilla->files;
+  for my $file ($self->zilla->files->flatten) {
+    next unless $self->exclude_file($file);
 
-  @$files = grep {
-    $self->exclude_file($_)
-    ? do { $self->log_debug([ 'pruning %s', $_->name ]); 0 }
-    : 1
-  } @$files;
+    $self->log_debug([ 'pruning %s', $file->name ]);
+
+    $self->zilla->prune_file($file);
+  }
 
   return;
 }
@@ -47,7 +47,7 @@ Dist::Zilla::Plugin::PruneCruft - prune stuff that you probably don't mean to in
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 SYNOPSIS
 
@@ -64,7 +64,7 @@ but for now that exclusion exclusion mechanism has been excluded.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
