@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PruneFiles;
 BEGIN {
-  $Dist::Zilla::Plugin::PruneFiles::VERSION = '3.101390';
+  $Dist::Zilla::Plugin::PruneFiles::VERSION = '4.101800';
 }
 # ABSTRACT: prune arbirary files from the dist
 use Moose;
@@ -21,14 +21,16 @@ has filenames => (
 sub prune_files {
   my ($self) = @_;
 
-  my $files = $self->zilla->files;
+  my %file = map {; $_->name => $_ } $self->zilla->files->flatten;
 
-  for my $filename ($self->filenames->flatten) {
-    @$files = $files->grep(sub {
-      (($_->name ne $filename) && ($_->name !~ m{\A\Q$filename\E/}))
-      ? 1
-      : do { $self->log_debug([ 'pruning %s', $_->name ]); 0 }
-    })->flatten;
+  for my $exclude ($self->filenames->flatten) {
+    for my $name (keys %file) {
+      next unless $name eq $exclude || $name =~ m{\A\Q$exclude\E/};
+
+      $self->log_debug([ 'pruning %s', $name ]);
+
+      $self->zilla->prune_file($file{$name});
+    }
   }
 
   return;
@@ -47,7 +49,7 @@ Dist::Zilla::Plugin::PruneFiles - prune arbirary files from the dist
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 SYNOPSIS
 
@@ -68,7 +70,7 @@ This is an arrayref of filenames to be pruned from the distribution.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
