@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::Filter;
 BEGIN {
-  $Dist::Zilla::PluginBundle::Filter::VERSION = '3.101390';
+  $Dist::Zilla::PluginBundle::Filter::VERSION = '4.101800';
 }
 # ABSTRACT: use another bundle, with some plugins removed
 use Moose;
@@ -10,28 +10,38 @@ with 'Dist::Zilla::Role::PluginBundle';
 use Dist::Zilla::Util;
 
 
-sub mvp_multivalue_args { qw(remove) }
+sub mvp_multivalue_args { qw(remove -remove) }
 
 sub bundle_config {
   my ($self, $section) = @_;
   my $class = (ref $self) || $self;
 
-  my $config = $section->{payload};
+  my $config = {};
+
+  my $has_filter_args = $section->{payload}->keys->grep(sub { /^-/ })->length;
+  for my $key ($section->{payload}->keys->flatten) {
+    my $val = $section->{payload}->{$key};
+    my $target = $has_filter_args && ($key !~ /^-/)
+      ? 'bundle'
+      : 'filter';
+    $key =~ s/^-// if $target eq 'filter';
+    $config->{$target}->{$key} = $val;
+  }
 
   Carp::croak("no bundle given for bundle filter")
-    unless my $bundle = $config->{bundle};
+    unless my $bundle = $config->{filter}->{bundle};
 
   $bundle = Dist::Zilla::Util->expand_config_package_name($bundle);
 
-  eval "require $bundle; 1" or die;
+  Class::MOP::load_class($bundle);
 
   my @plugins = $bundle->bundle_config({
     name    => $section->{name}, # not 100% sure about this -- rjbs, 2010-03-06
     package => $bundle,
-    payload => {},
+    payload => $config->{bundle} || {},
   });
 
-  return @plugins unless my $remove = $config->{remove};
+  return @plugins unless my $remove = $config->{filter}->{remove};
 
   require List::MoreUtils;
   for my $i (reverse 0 .. $#plugins) {
@@ -56,26 +66,29 @@ Dist::Zilla::PluginBundle::Filter - use another bundle, with some plugins remove
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
 
   [@Filter]
-  bundle = @Classic
-  remove = PodVersion
-  remove = Manifest
+  -bundle = @Classic
+  -remove = PodVersion
+  -remove = Manifest
+  option = for_classic
 
 =head1 DESCRIPTION
 
 This plugin bundle actually wraps and modified another plugin bundle.  It
-includes all the configuration for the bundle named in the C<bundle> attribute,
-but removes all the entries whose package is given in the C<remove> attributes.
+includes all the configuration for the bundle named in the C<-bundle> attribute,
+but removes all the entries whose package is given in the C<-remove> attributes.
+
+Options not prefixed with C<-> will be passed to the bundle to be filtered.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
