@@ -1,12 +1,17 @@
 package Dist::Zilla::Role::Chrome;
 BEGIN {
-  $Dist::Zilla::Role::Chrome::VERSION = '3.101390';
+  $Dist::Zilla::Role::Chrome::VERSION = '4.101800';
 }
-use Moose::Role;
 # ABSTRACT: something that provides a user interface for Dist::Zilla
+use Moose::Role;
 
 requires 'logger';
 
+requires 'prompt_str';
+requires 'prompt_yn';
+requires 'prompt_any_key';
+
+
 1;
 
 __END__
@@ -18,11 +23,11 @@ Dist::Zilla::Role::Chrome - something that provides a user interface for Dist::Z
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
