@@ -1,11 +1,17 @@
 package Dist::Zilla::Role::PluginBundle;
 BEGIN {
-  $Dist::Zilla::Role::PluginBundle::VERSION = '3.101390';
+  $Dist::Zilla::Role::PluginBundle::VERSION = '4.101800';
 }
 # ABSTRACT: something that bundles a bunch of plugins
 use Moose::Role;
 
 
+sub register_component {
+  my ($class, $name, $arg, $self) = @_;
+  # ... we should register a placeholder so MetaConfig can tell us about the
+  # pluginbundle that was loaded
+}
+
 requires 'bundle_config';
 
 no Moose::Role;
@@ -20,7 +26,7 @@ Dist::Zilla::Role::PluginBundle - something that bundles a bunch of plugins
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 DESCRIPTION
 
@@ -31,7 +37,7 @@ configure the bundle.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
