@@ -1,15 +1,21 @@
 package Dist::Zilla::Types;
 BEGIN {
-  $Dist::Zilla::Types::VERSION = '3.101390';
+  $Dist::Zilla::Types::VERSION = '4.101800';
 }
 # ABSTRACT: dzil-specific type library
 
 
-use MooseX::Types -declare => [qw(License)];
-use MooseX::Types::Moose qw(Str);
+use MooseX::Types -declare => [qw(License OneZero YesNoStr)];
+use MooseX::Types::Moose qw(Str Int);
 
 subtype License, as class_type('Software::License');
 
+subtype OneZero, as Str, where { $_ eq '0' or $_ eq '1' };
+
+subtype YesNoStr, as Str, where { /\A(?:y|ye|yes)\Z/i or /\A(?:n|no)\Z/i };
+
+coerce OneZero, from YesNoStr, via { /\Ay/i ? 1 : 0 };
+
 1;
 
 __END__
@@ -21,7 +27,7 @@ Dist::Zilla::Types - dzil-specific type library
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 OVERVIEW
 
@@ -33,7 +39,7 @@ that's what you want.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
