@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::Util;
 BEGIN {
-  $Dist::Zilla::Util::VERSION = '3.101390';
+  $Dist::Zilla::Util::VERSION = '4.101800';
 }
 # ABSTRACT: random snippets of code that Dist::Zilla wants
 
@@ -11,9 +11,6 @@ use String::RewritePrefix 0.002; # better string context behavior
 {
   package
     Dist::Zilla::Util::PEA;
-BEGIN {
-  $Dist::Zilla::Util::PEA::VERSION = '3.101390';
-}
   use Pod::Eventual 0.091480; # better nonpod/blank events
   use base 'Pod::Eventual';
   sub _new  { bless {} => shift; }
@@ -38,7 +35,7 @@ BEGIN {
     }
 
     return unless $self->{in_name};
-    
+
     if (
       $event->{type} eq 'text'
       and $event->{content} =~ /^\S+\s+-+\s+(.+)$/
@@ -64,7 +61,7 @@ sub expand_config_package_name {
     {
       '=' => '',
       '@' => 'Dist::Zilla::PluginBundle::',
-      '!' => 'Dist::Zilla::App::Command::',
+      '%' => 'Dist::Zilla::Stash::',
       ''  => 'Dist::Zilla::Plugin::',
     },
     $package,
@@ -84,7 +81,7 @@ Dist::Zilla::Util - random snippets of code that Dist::Zilla wants
 
 =head1 VERSION
 
-version 3.101390
+version 4.101800
 
 =head1 METHODS
 
@@ -94,7 +91,7 @@ This method, I<which is likely to change or go away>, tries to guess the
 abstract of a given file, assuming that it's Perl code.  It looks for a POD
 C<=head1> section called "NAME" or a comment beginning with C<ABSTRACT:>.
 
-=head2 expand_config_package_name 
+=head2 expand_config_package_name
 
   my $pkg_name = Util->expand_config_package_name($string);
 
@@ -104,7 +101,7 @@ more information.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
